{% extends "cradmin_resetpassword/base.django.html" %}
{% load crispy_forms_tags %}
{% load i18n %}


{% block subtitle %}
    {% trans "Check your email" %}
{% endblock subtitle %}

{% block pageheader-inner %}
    <h1>
        {% trans "Check your email" %}
    </h1>
{% endblock pageheader-inner %}

{% block content %}
    <p>
        {% trans "We have sent you an email. Click the link in the email to reset your password." %}
    </p>
    <p>
        {% blocktrans with email_subject=email_subject %}If you do not see the email, check your junk folder or try searching for "{{ email_subject }}".{% endblocktrans %}
    </p>
{% endblock content %}
