<button type="submit"
        name="{% if input.name|wordcount > 1 %}{{ input.name|slugify }}{% else %}{{ input.name }}{% endif %}"
        class="{{ input.field_classes }}"
        id="{% if input.id %}{{ input.id }}{% else %}{{ input.input_type }}-id-{{ input.name|slugify }}{% endif %}"
        {{ input.flat_attrs|safe }}
        {{ input.extra_button_attributes|safe }}>
    {% block label %}
        {% if input.icon_cssclass %}
            <span class="{{ input.icon_cssclass }}"></span>
        {% endif %} 
        {{ input.value }}
    {% endblock label %}
</button>
