{% extends "django_cradmin/viewhelpers/multiselect2view/base.django.html" %}

{% block columnlayout_extra_cssclass %}
    django-cradmin-multiselect2-columnlayout-2
{% endblock columnlayout_extra_cssclass %}
