{% extends "django_cradmin/base.django.html" %}
{% load i18n %}

{% block title %}
    {{ pagetitle }}
{% endblock title %}

{% block pageheader-inner %}
    <h1>
        {% block heading %}
            {{ pagetitle }}
        {% endblock heading %}
    </h1>
{% endblock pageheader-inner %}

{% block content %}

    {% block delete-form %}
        <form action="{{ request.build_absolute_uri }}" method="post" class="django-cradmin-form">{% csrf_token %}
            <div class="container">
                {% block deletequestion %}
                    <div id="deleteview-preview">
                        <p>{{ confirm_message }}</p>
                    </div>
                {% endblock deletequestion %}
                <button type="submit" class="btn btn-danger">{{ delete_button_label }}</button>
                <a class="btn btn-cancel" django-cradmin-back>{% trans "Cancel" %}</a>
            </div>
        </form>
    {% endblock delete-form%}
{% endblock content %}
