{% extends "cradmin_resetpassword/base.django.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block subtitle %}
    {% trans "Find your account" %}
{% endblock subtitle %}

{% block pageheader-inner %}
    <h1>{% trans "Find your account" %}</h1>
    <p>{% trans "Type in your email-address" %}</p>
{% endblock pageheader-inner %}

{% block content %}
    {% crispy form formhelper %}
{% endblock content %}
